@@ -15,6 +15,7 @@ import sqlalchemy as sa
 import datetime
 import random
 import string
+import json
 from builtins import object
 from builtins import range
 from builtins import str
@@ -628,11 +629,7 @@ class MTurkServicesWrapper(object):
         return {'hit_tally': num_hits}
 
     def _get_local_hitids(self):
-        participant_hitids = [
-            part.hitid for part in Participant.query.distinct(Participant.hitid)]
-        hit_hitids = [hit.hitid for hit in Hit.query.distinct(Hit.hitid)]
-        my_hitids = list(set(participant_hitids + hit_hitids))
-        return my_hitids
+        return [hit.hitid for hit in Hit.query.distinct(Hit.hitid)]
 
     @amt_services_wrapper_response
     def get_active_hits(self, all_studies=False):
@@ -664,7 +661,7 @@ class MTurkServicesWrapper(object):
 
     def _get_hits(self, all_studies=False):
         # get all hits from amt
-        # then filter to just the ones that have an id that appears in either local Hit or Worker tables
+        # then filter to just the ones that have an id that appears in the local Hit table
         response = self.amt_services.get_all_hits()
         if not response.success:
             raise response.exception
@@ -828,6 +825,18 @@ class MTurkServicesWrapper(object):
         block_quals = self.config.get('HIT Configuration', 'block_quals', fallback=None)
         if block_quals:
             block_qualification_ids.extend(block_quals.split(','))
+        
+        advanced_quals_path = self.config.get('HIT Configuration', 'advanced_quals_path', fallback=None)
+        advanced_qualifications = []
+        if advanced_quals_path:
+            with open(advanced_quals_path) as f:
+                advanced_qualifications = json.load(f)
+                if not isinstance(advanced_qualifications, list):
+                    raise PsiturkException(message=f'JSON file "{advanced_quals_path}" must be a list of dicts')
+                else:
+                    for el in advanced_qualifications:
+                        if not isinstance(el, dict):
+                            raise PsiturkException(message=f'JSON file "{advanced_quals_path}" must be a list of dicts')
 
         hit_config = {
             "ad_location": ad_url,
@@ -845,6 +854,7 @@ class MTurkServicesWrapper(object):
             "require_master_workers": self.config.getboolean('HIT Configuration',
                                                              'require_master_workers'),
             "require_qualification_ids": require_qualification_ids,
-            "block_qualification_ids": block_qualification_ids
+            "block_qualification_ids": block_qualification_ids,
+            "advanced_qualifications": advanced_qualifications
         }
         return hit_config
